@@ -19,46 +19,58 @@
 
 #define IMAGE_DEFINE(image)                                                                        \
     void image##_draw(image *self, int X, int Y, int W, int H) {                                   \
-        LOCK(self->draw(X, Y, W, H);)                                                              \
+        LOCK(self->draw(X, Y, W, H));                                                              \
+    }                                                                                              \
+    void image##_draw_ext(image *self, int X, int Y, int W, int H, int cx, int cy) {               \
+        LOCK(self->draw(X, Y, W, H, cx, cy));                                                      \
     }                                                                                              \
     int image##_width(image *self) {                                                               \
-        LOCK(auto ret = self->w();) return ret;                                                    \
+        LOCK(auto ret = self->w());                                                                \
+        return ret;                                                                                \
     }                                                                                              \
     int image##_height(image *self) {                                                              \
-        LOCK(auto ret = self->h();) return ret;                                                    \
+        LOCK(auto ret = self->h());                                                                \
+        return ret;                                                                                \
     }                                                                                              \
     void image##_delete(image *self) {                                                             \
         delete self;                                                                               \
     }                                                                                              \
     int image##_count(image *self) {                                                               \
-        LOCK(auto ret = self->count();) return ret;                                                \
+        LOCK(auto ret = self->count());                                                            \
+        return ret;                                                                                \
     }                                                                                              \
     const char *const *image##_data(image *self) {                                                 \
-        LOCK(auto ret = self->data();) return ret;                                                 \
+        LOCK(auto ret = self->data());                                                             \
+        return ret;                                                                                \
     }                                                                                              \
     image *image##_copy(image *self) {                                                             \
         return (image *)self->copy();                                                              \
     }                                                                                              \
     void image##_scale(image *self, int width, int height, int proportional, int can_expand) {     \
-        LOCK(self->scale(width, height, proportional, can_expand);)                                \
+        LOCK(self->scale(width, height, proportional, can_expand));                                \
     }                                                                                              \
     int image##_fail(image *self) {                                                                \
-        LOCK(auto ret = self->fail();) return ret;                                                 \
+        LOCK(auto ret = self->fail());                                                             \
+        return ret;                                                                                \
     }                                                                                              \
     int image##_data_w(const image *self) {                                                        \
-        LOCK(auto ret = self->data_w();) return ret;                                               \
+        LOCK(auto ret = self->data_w());                                                           \
+        return ret;                                                                                \
     }                                                                                              \
     int image##_data_h(const image *self) {                                                        \
-        LOCK(auto ret = self->data_h();) return ret;                                               \
+        LOCK(auto ret = self->data_h());                                                           \
+        return ret;                                                                                \
     }                                                                                              \
     int image##_d(const image *self) {                                                             \
-        LOCK(auto ret = self->d();) return ret;                                                    \
+        LOCK(auto ret = self->d());                                                                \
+        return ret;                                                                                \
     }                                                                                              \
     int image##_ld(const image *self) {                                                            \
-        LOCK(auto ret = self->ld();) return ret;                                                   \
+        LOCK(auto ret = self->ld());                                                               \
+        return ret;                                                                                \
     }                                                                                              \
     void image##_inactive(image *self) {                                                           \
-        LOCK(self->inactive();)                                                                    \
+        LOCK(self->inactive());                                                                    \
     }
 
 IMAGE_DEFINE(Fl_JPEG_Image)
@@ -100,7 +112,7 @@ Fl_SVG_Image *Fl_SVG_Image_from(const char *data) {
 }
 
 void Fl_SVG_Image_normalize(Fl_SVG_Image *self) {
-    LOCK(self->normalize();)
+    LOCK(self->normalize());
 }
 
 IMAGE_DEFINE(Fl_BMP_Image)
@@ -189,7 +201,11 @@ Fl_RGB_Image *Fl_RGB_Image_from_data(const unsigned char *bits, int W, int H, in
 }
 
 void Fl_Shared_Image_draw(Fl_Shared_Image *self, int X, int Y, int W, int H) {
-    LOCK(self->draw(X, Y, W, H);)
+    LOCK(self->draw(X, Y, W, H));
+}
+
+void Fl_Shared_Image_draw_ext(Fl_Shared_Image *self, int X, int Y, int W, int H, int cx, int cy) {
+    LOCK(self->draw(X, Y, W, H, cx, cy));
 }
 
 int Fl_Shared_Image_width(Fl_Shared_Image *self) {
@@ -223,7 +239,7 @@ Fl_Shared_Image *Fl_Shared_Image_copy(Fl_Shared_Image *self) {
 
 void Fl_Shared_Image_scale(Fl_Shared_Image *self, int width, int height, int proportional,
                            int can_expand) {
-    LOCK(self->scale(width, height, proportional, can_expand);)
+    LOCK(self->scale(width, height, proportional, can_expand));
 }
 
 Fl_Shared_Image *Fl_Shared_Image_get(const char *name, int W, int H) {
@@ -262,7 +278,7 @@ int Fl_Shared_Image_ld(const Fl_Shared_Image *self) {
 }
 
 void Fl_Shared_Image_inactive(Fl_Shared_Image *self) {
-    LOCK(self->inactive();)
+    LOCK(self->inactive());
 }
 
 void Fl_register_images(void) {
